Package 'avlm'

Title: Safe Anytime Valid Inference for Linear Models
Description: Implements the anytime valid methodology for linear models documented in "Anytime-Valid Linear Models and Regression Adjusted Causal Inference in Randomized Experiments" <doi:10.48550/arXiv.2210.08589>.
Authors: Michael Lindon [aut, cre]
Maintainer: Michael Lindon <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-05-27 08:24:01 UTC
Source: https://github.com/michaellindon/avlm

Help Index